==> datavan-4.2.0.tgz: package/lib/es6/react/createDatavanContext.js <==
import _pick from "lodash/pick";
import _compact from "lodash/compact";
import _uniq from "lodash/uniq";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } _setPrototypeOf(subClass.prototype, superClass && superClass.prototype); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.getPrototypeOf || function _getPrototypeOf(o) { return o.__proto__; }; return _getPrototypeOf(o); }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { createElement, Component } from 'react';
import createReactContext from 'create-react-context';
import bitsObserver from './bitsObserver';
import createDb from '../db';
import { createBatchMemoizer } from '../cache-util';
export var getMemoizeHoc = function getMemoizeHoc(VanConsumer) {
  return function (propKeys, mapFunc) {
    propKeys = _uniq(_compact(propKeys));
    return function (BaseComponent) {
      return function (props) {
        return createElement(VanConsumer, props, function (db) {
          var dataProps = mapFunc && db.memoize(mapFunc, _pick(props, propKeys), props);
          return createElement(BaseComponent, _objectSpread({}, props, {
            db: db
          }, dataProps));
        });
      };
    };
  };
};

var createDatavanContext = function createDatavanContext(config) {
  var _bitsObserver = bitsObserver(config),
      calcChangedBits = _bitsObserver.calcChangedBits,
      getObservedBits = _bitsObserver.getObservedBits;

  var _createReactContext = createReactContext(null, calcChangedBits),
      Provider = _createReactContext.Provider,
      Consumer = _createReactContext.Consumer;

  var VanProvider =
  /*#__PURE__*/
  function (_Component) {
    function VanProvider(props) {
      var _this;

      _classCallCheck(this, VanProvider);

      _this = _possibleConstructorReturn(this, _getPrototypeOf(VanProvider).call(this, props)); // TODO may pass upper provider db instead of config here

      var db = props.initDb ? props.initDb(config) : props.db || createDb(config);
      _this.state = db;
      return _this;
    }

    _createClass(VanProvider, [{
      key: "componentDidMount",
      value: function componentDidMount() {
        var _this2 = this;

        this.unsubscribe = this.state.subscribe(function (change) {
          return _this2.setState(change);
        });
      }
    }, {
      key: "componentWillUnmount",
      value: function componentWillUnmount() {
        this.unsubscribe();
      }
    }, {
      key: "render",
      value: function render() {
        return createElement(Provider, {
          value: this.state
        }, this.props.children);
      }
    }]);

    _inherits(VanProvider, _Component);

    return VanProvider;
  }(Component);
  /* eslint-disable react/no-multi-comp */


  var VanConsumer =
  /*#__PURE__*/
  function (_Component2) {
    function VanConsumer() {
      var _getPrototypeOf2;

      var _temp, _this3;

      _classCallCheck(this, VanConsumer);

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      return _possibleConstructorReturn(_this3, (_temp = _this3 = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(VanConsumer)).call.apply(_getPrototypeOf2, [this].concat(args))), _defineProperty(_defineProperty(_assertThisInitialized(_assertThisInitialized(_this3)), "observedBits", getObservedBits(_this3.props.observe)), "memoizer", createBatchMemoizer(function () {
        return _this3.setState({
          cacheAt: Date.now()
        });
      })), _temp));
    }

    _createClass(VanConsumer, [{
      key: "UNSAFE_componentWillReceiveProps",
      // eslint-disable-next-line
      value: function UNSAFE_componentWillReceiveProps(nextProps) {
        if (this.props.observe !== nextProps.observe) {
          this.observedBits = getObservedBits(nextProps.observe);
        }
      }
    }, {
      key: "render",
      value: function render() {
        var _this4 = this;

        var props = this.props;
        return createElement(Consumer, _objectSpread({}, props, {
          observedBits: this.observedBits
        }), function (db) {
          return props.children(_this4.memoizer.newBatch(db));
        });
      }
    }]);

    _inherits(VanConsumer, _Component2);

    return VanConsumer;
  }(Component);

  Object.assign(VanConsumer, {
    Provider: VanProvider,
    config: config,
    hoc: function hoc(propKeys, mapFunc) {
      return getMemoizeHoc(VanConsumer)(propKeys, mapFunc);
    }
  });
  return VanConsumer;
};

export default createDatavanContext;

==> datavan-4.2.1.tgz: package/lib/es6/react/createDatavanContext.js <==
import _pick from "lodash/pick";
import _compact from "lodash/compact";
import _uniq from "lodash/uniq";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } _setPrototypeOf(subClass.prototype, superClass && superClass.prototype); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.getPrototypeOf || function _getPrototypeOf(o) { return o.__proto__; }; return _getPrototypeOf(o); }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { createElement, Component } from 'react';
import createReactContext from 'create-react-context';
import bitsObserver from './bitsObserver';
import createDb from '../db';
import { createBatchMemoizer } from '../cache-util';
export var getMemoizeHoc = function getMemoizeHoc(VanConsumer) {
  return function (propKeys, mapFunc) {
    propKeys = _uniq(_compact(propKeys));
    return function (BaseComponent) {
      return function (props) {
        return createElement(VanConsumer, props, function (db) {
          var dataProps = mapFunc && db.memoize(mapFunc, _pick(props, propKeys), props);
          return createElement(BaseComponent, _objectSpread({}, props, {
            db: db
          }, dataProps));
        });
      };
    };
  };
};

var createDatavanContext = function createDatavanContext(config) {
  var _bitsObserver = bitsObserver(config),
      calcChangedBits = _bitsObserver.calcChangedBits,
      getObservedBits = _bitsObserver.getObservedBits;

  var _createReactContext = createReactContext(null, calcChangedBits),
      Provider = _createReactContext.Provider,
      Consumer = _createReactContext.Consumer;

  var VanProvider =
  /*#__PURE__*/
  function (_Component) {
    function VanProvider(props) {
      var _this;

      _classCallCheck(this, VanProvider);

      _this = _possibleConstructorReturn(this, _getPrototypeOf(VanProvider).call(this, props)); // TODO may pass upper provider db instead of config here

      var db = props.initDb ? props.initDb(config) : props.db || createDb(config);
      _this.state = db;
      return _this;
    }

    _createClass(VanProvider, [{
      key: "componentDidMount",
      value: function componentDidMount() {
        var _this2 = this;

        this.unsubscribe = this.state.subscribe(function (change) {
          return _this2.setState(change);
        });
      }
    }, {
      key: "componentWillUnmount",
      value: function componentWillUnmount() {
        this.unsubscribe();
      }
    }, {
      key: "render",
      value: function render() {
        return createElement(Provider, {
          value: this.state
        }, this.props.children);
      }
    }]);

    _inherits(VanProvider, _Component);

    return VanProvider;
  }(Component);
  /* eslint-disable react/no-multi-comp */


  var VanConsumer =
  /*#__PURE__*/
  function (_Component2) {
    function VanConsumer() {
      var _getPrototypeOf2;

      var _temp, _this3;

      _classCallCheck(this, VanConsumer);

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      return _possibleConstructorReturn(_this3, (_temp = _this3 = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(VanConsumer)).call.apply(_getPrototypeOf2, [this].concat(args))), _defineProperty(_assertThisInitialized(_assertThisInitialized(_this3)), "observedBits", getObservedBits(_this3.props.observe)), _defineProperty(_assertThisInitialized(_assertThisInitialized(_this3)), "memoizer", createBatchMemoizer(function () {
        return _this3.setState({
          cacheAt: Date.now()
        });
      })), _temp));
    }

    _createClass(VanConsumer, [{
      key: "UNSAFE_componentWillReceiveProps",
      // eslint-disable-next-line
      value: function UNSAFE_componentWillReceiveProps(nextProps) {
        if (this.props.observe !== nextProps.observe) {
          this.observedBits = getObservedBits(nextProps.observe);
        }
      }
    }, {
      key: "render",
      value: function render() {
        var _this4 = this;

        var props = this.props;
        return createElement(Consumer, _objectSpread({}, props, {
          observedBits: this.observedBits
        }), function (db) {
          return props.children(_this4.memoizer.newBatch(db));
        });
      }
    }]);

    _inherits(VanConsumer, _Component2);

    return VanConsumer;
  }(Component);

  Object.assign(VanConsumer, {
    Provider: VanProvider,
    config: config,
    hoc: function hoc(propKeys, mapFunc) {
      return getMemoizeHoc(VanConsumer)(propKeys, mapFunc);
    }
  });
  return VanConsumer;
};

export default createDatavanContext;
